@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -20,6 +20,9 @@ FAILEDOPERATION_ARREARSERROR = 'FailedOperation.ArrearsError'
 # 今日次数达到限制。
 FAILEDOPERATION_COUNTLIMITERROR = 'FailedOperation.CountLimitError'
 
+# 数据源查询失败。
+FAILEDOPERATION_DATASOURCEQUERYFAILED = 'FailedOperation.DataSourceQueryFailed'
+
 # 检测失败。
 FAILEDOPERATION_DETECTFAILED = 'FailedOperation.DetectFailed'
 
@@ -65,6 +68,9 @@ FAILEDOPERATION_MULTICARDERROR = 'FailedOperation.MultiCardError'
 # 非香港身份证。
 FAILEDOPERATION_NOHKIDCARD = 'FailedOperation.NoHKIDCard'
 
+# 非马来身份证。
+FAILEDOPERATION_NOMASIDCARD = 'FailedOperation.NoMASIDCard'
+
 # 非护照。
 FAILEDOPERATION_NOPASSPORT = 'FailedOperation.NoPassport'
 
@@ -101,5 +107,8 @@ LIMITEXCEEDED_TOOLARGEFILEERROR = 'LimitExceeded.TooLargeFileError'
 # 发票不存在。
 RESOURCENOTFOUND_NOINVOICE = 'ResourceNotFound.NoInvoice'
 
+# 不支持当天发票查询。
+RESOURCENOTFOUND_NOTSUPPORTCURRENTINVOICEQUERY = 'ResourceNotFound.NotSupportCurrentInvoiceQuery'
+
 # 计费状态异常。
 RESOURCESSOLDOUT_CHARGESTATUSEXCEPTION = 'ResourcesSoldOut.ChargeStatusException'
